betty.path module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.path module

Provide path handling utilities.

betty.path.rootname(source_path: pathlib._local.Path) → pathlib._local.Path

  Get a path’s root name, such as / or `C:`.

  Parameters:

    source_path (`pathlib._local.Path`)

  Return type:

    `pathlib._local.Path`